# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .bgp import (
    BGPResource,
    AsyncBGPResource,
    BGPResourceWithRawResponse,
    AsyncBGPResourceWithRawResponse,
    BGPResourceWithStreamingResponse,
    AsyncBGPResourceWithStreamingResponse,
)
from .ips import (
    IPsResource,
    AsyncIPsResource,
    IPsResourceWithRawResponse,
    AsyncIPsResourceWithRawResponse,
    IPsResourceWithStreamingResponse,
    AsyncIPsResourceWithStreamingResponse,
)
from .top import (
    TopResource,
    AsyncTopResource,
    TopResourceWithRawResponse,
    AsyncTopResourceWithRawResponse,
    TopResourceWithStreamingResponse,
    AsyncTopResourceWithStreamingResponse,
)
from .rpki import (
    RPKIResource,
    AsyncRPKIResource,
    RPKIResourceWithRawResponse,
    AsyncRPKIResourceWithRawResponse,
    RPKIResourceWithStreamingResponse,
    AsyncRPKIResourceWithStreamingResponse,
)
from .leaks import (
    LeaksResource,
    AsyncLeaksResource,
    LeaksResourceWithRawResponse,
    AsyncLeaksResourceWithRawResponse,
    LeaksResourceWithStreamingResponse,
    AsyncLeaksResourceWithStreamingResponse,
)
from .routes import (
    RoutesResource,
    AsyncRoutesResource,
    RoutesResourceWithRawResponse,
    AsyncRoutesResourceWithRawResponse,
    RoutesResourceWithStreamingResponse,
    AsyncRoutesResourceWithStreamingResponse,
)
from .hijacks import (
    HijacksResource,
    AsyncHijacksResource,
    HijacksResourceWithRawResponse,
    AsyncHijacksResourceWithRawResponse,
    HijacksResourceWithStreamingResponse,
    AsyncHijacksResourceWithStreamingResponse,
)

__all__ = [
    "LeaksResource",
    "AsyncLeaksResource",
    "LeaksResourceWithRawResponse",
    "AsyncLeaksResourceWithRawResponse",
    "LeaksResourceWithStreamingResponse",
    "AsyncLeaksResourceWithStreamingResponse",
    "TopResource",
    "AsyncTopResource",
    "TopResourceWithRawResponse",
    "AsyncTopResourceWithRawResponse",
    "TopResourceWithStreamingResponse",
    "AsyncTopResourceWithStreamingResponse",
    "HijacksResource",
    "AsyncHijacksResource",
    "HijacksResourceWithRawResponse",
    "AsyncHijacksResourceWithRawResponse",
    "HijacksResourceWithStreamingResponse",
    "AsyncHijacksResourceWithStreamingResponse",
    "RoutesResource",
    "AsyncRoutesResource",
    "RoutesResourceWithRawResponse",
    "AsyncRoutesResourceWithRawResponse",
    "RoutesResourceWithStreamingResponse",
    "AsyncRoutesResourceWithStreamingResponse",
    "IPsResource",
    "AsyncIPsResource",
    "IPsResourceWithRawResponse",
    "AsyncIPsResourceWithRawResponse",
    "IPsResourceWithStreamingResponse",
    "AsyncIPsResourceWithStreamingResponse",
    "RPKIResource",
    "AsyncRPKIResource",
    "RPKIResourceWithRawResponse",
    "AsyncRPKIResourceWithRawResponse",
    "RPKIResourceWithStreamingResponse",
    "AsyncRPKIResourceWithStreamingResponse",
    "BGPResource",
    "AsyncBGPResource",
    "BGPResourceWithRawResponse",
    "AsyncBGPResourceWithRawResponse",
    "BGPResourceWithStreamingResponse",
    "AsyncBGPResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, Optional, cast

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import path_template, maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._wrappers import ResultWrapper
from ...pagination import SyncSinglePage, AsyncSinglePage
from ..._base_client import AsyncPaginator, make_request_options
from ...types.hyperdrive import config_edit_params, config_create_params, config_update_params
from ...types.hyperdrive.hyperdrive import Hyperdrive

__all__ = ["ConfigsResource", "AsyncConfigsResource"]


class ConfigsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ConfigsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return ConfigsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ConfigsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return ConfigsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        account_id: str,
        name: str,
        origin: config_create_params.Origin,
        caching: config_create_params.Caching | Omit = omit,
        mtls: config_create_params.MTLS | Omit = omit,
        origin_connection_limit: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Hyperdrive:
        """
        Creates and returns a new Hyperdrive configuration.

        Args:
          account_id: Define configurations using a unique string identifier.

          name: The name of the Hyperdrive configuration. Used to identify the configuration in
              the Cloudflare dashboard and API.

          mtls: mTLS configuration for the origin connection. Cannot be used with VPC Service
              origins; TLS must be managed on the VPC Service.

          origin_connection_limit: The (soft) maximum number of connections the Hyperdrive is allowed to make to
              the origin database.

              Maximum allowed: 20 for free tier accounts, 100 for paid tier accounts. If not
              specified, defaults to 20 for free tier and 60 for paid tier. Contact Cloudflare
              if you need a higher limit.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._post(
            path_template("/accounts/{account_id}/hyperdrive/configs", account_id=account_id),
            body=maybe_transform(
                {
                    "name": name,
                    "origin": origin,
                    "caching": caching,
                    "mtls": mtls,
                    "origin_connection_limit": origin_connection_limit,
                },
                config_create_params.ConfigCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Hyperdrive]._unwrapper,
            ),
            cast_to=cast(Type[Hyperdrive], ResultWrapper[Hyperdrive]),
        )

    def update(
        self,
        hyperdrive_id: str,
        *,
        account_id: str,
        name: str,
        origin: config_update_params.Origin,
        caching: config_update_params.Caching | Omit = omit,
        mtls: config_update_params.MTLS | Omit = omit,
        origin_connection_limit: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Hyperdrive:
        """
        Updates and returns the specified Hyperdrive configuration.

        Args:
          account_id: Define configurations using a unique string identifier.

          hyperdrive_id: Define configurations using a unique string identifier.

          name: The name of the Hyperdrive configuration. Used to identify the configuration in
              the Cloudflare dashboard and API.

          mtls: mTLS configuration for the origin connection. Cannot be used with VPC Service
              origins; TLS must be managed on the VPC Service.

          origin_connection_limit: The (soft) maximum number of connections the Hyperdrive is allowed to make to
              the origin database.

              Maximum allowed: 20 for free tier accounts, 100 for paid tier accounts. If not
              specified, defaults to 20 for free tier and 60 for paid tier. Contact Cloudflare
              if you need a higher limit.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not hyperdrive_id:
            raise ValueError(f"Expected a non-empty value for `hyperdrive_id` but received {hyperdrive_id!r}")
        return self._put(
            path_template(
                "/accounts/{account_id}/hyperdrive/configs/{hyperdrive_id}",
                account_id=account_id,
                hyperdrive_id=hyperdrive_id,
            ),
            body=maybe_transform(
                {
                    "name": name,
                    "origin": origin,
                    "caching": caching,
                    "mtls": mtls,
                    "origin_connection_limit": origin_connection_limit,
                },
                config_update_params.ConfigUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Hyperdrive]._unwrapper,
            ),
            cast_to=cast(Type[Hyperdrive], ResultWrapper[Hyperdrive]),
        )

    def list(
        self,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncSinglePage[Hyperdrive]:
        """
        Returns a list of Hyperdrives.

        Args:
          account_id: Define configurations using a unique string identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/hyperdrive/configs", account_id=account_id),
            page=SyncSinglePage[Hyperdrive],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=Hyperdrive,
        )

    def delete(
        self,
        hyperdrive_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Deletes the specified Hyperdrive.

        Args:
          account_id: Define configurations using a unique string identifier.

          hyperdrive_id: Define configurations using a unique string identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not hyperdrive_id:
            raise ValueError(f"Expected a non-empty value for `hyperdrive_id` but received {hyperdrive_id!r}")
        return self._delete(
            path_template(
                "/accounts/{account_id}/hyperdrive/configs/{hyperdrive_id}",
                account_id=account_id,
                hyperdrive_id=hyperdrive_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[object]]._unwrapper,
            ),
            cast_to=cast(Type[object], ResultWrapper[object]),
        )

    def edit(
        self,
        hyperdrive_id: str,
        *,
        account_id: str,
        caching: config_edit_params.Caching | Omit = omit,
        mtls: config_edit_params.MTLS | Omit = omit,
        name: str | Omit = omit,
        origin: config_edit_params.Origin | Omit = omit,
        origin_connection_limit: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Hyperdrive:
        """Patches and returns the specified Hyperdrive configuration.

        Custom caching
        settings are not kept if caching is disabled.

        Args:
          account_id: Define configurations using a unique string identifier.

          hyperdrive_id: Define configurations using a unique string identifier.

          mtls: mTLS configuration for the origin connection. Cannot be used with VPC Service
              origins; TLS must be managed on the VPC Service.

          name: The name of the Hyperdrive configuration. Used to identify the configuration in
              the Cloudflare dashboard and API.

          origin: Connect to a database through a Workers VPC Service. TLS settings (mTLS,
              sslmode) cannot be configured on the Hyperdrive when using a VPC Service origin;
              TLS must be managed on the VPC Service itself.

          origin_connection_limit: The (soft) maximum number of connections the Hyperdrive is allowed to make to
              the origin database.

              Maximum allowed: 20 for free tier accounts, 100 for paid tier accounts. If not
              specified, defaults to 20 for free tier and 60 for paid tier. Contact Cloudflare
              if you need a higher limit.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not hyperdrive_id:
            raise ValueError(f"Expected a non-empty value for `hyperdrive_id` but received {hyperdrive_id!r}")
        return self._patch(
            path_template(
                "/accounts/{account_id}/hyperdrive/configs/{hyperdrive_id}",
                account_id=account_id,
                hyperdrive_id=hyperdrive_id,
            ),
            body=maybe_transform(
                {
                    "caching": caching,
                    "mtls": mtls,
                    "name": name,
                    "origin": origin,
                    "origin_connection_limit": origin_connection_limit,
                },
                config_edit_params.ConfigEditParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Hyperdrive]._unwrapper,
            ),
            cast_to=cast(Type[Hyperdrive], ResultWrapper[Hyperdrive]),
        )

    def get(
        self,
        hyperdrive_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Hyperdrive:
        """
        Returns the specified Hyperdrive configuration.

        Args:
          account_id: Define configurations using a unique string identifier.

          hyperdrive_id: Define configurations using a unique string identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not hyperdrive_id:
            raise ValueError(f"Expected a non-empty value for `hyperdrive_id` but received {hyperdrive_id!r}")
        return self._get(
            path_template(
                "/accounts/{account_id}/hyperdrive/configs/{hyperdrive_id}",
                account_id=account_id,
                hyperdrive_id=hyperdrive_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Hyperdrive]._unwrapper,
            ),
            cast_to=cast(Type[Hyperdrive], ResultWrapper[Hyperdrive]),
        )


class AsyncConfigsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncConfigsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncConfigsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncConfigsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncConfigsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        account_id: str,
        name: str,
        origin: config_create_params.Origin,
        caching: config_create_params.Caching | Omit = omit,
        mtls: config_create_params.MTLS | Omit = omit,
        origin_connection_limit: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Hyperdrive:
        """
        Creates and returns a new Hyperdrive configuration.

        Args:
          account_id: Define configurations using a unique string identifier.

          name: The name of the Hyperdrive configuration. Used to identify the configuration in
              the Cloudflare dashboard and API.

          mtls: mTLS configuration for the origin connection. Cannot be used with VPC Service
              origins; TLS must be managed on the VPC Service.

          origin_connection_limit: The (soft) maximum number of connections the Hyperdrive is allowed to make to
              the origin database.

              Maximum allowed: 20 for free tier accounts, 100 for paid tier accounts. If not
              specified, defaults to 20 for free tier and 60 for paid tier. Contact Cloudflare
              if you need a higher limit.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._post(
            path_template("/accounts/{account_id}/hyperdrive/configs", account_id=account_id),
            body=await async_maybe_transform(
                {
                    "name": name,
                    "origin": origin,
                    "caching": caching,
                    "mtls": mtls,
                    "origin_connection_limit": origin_connection_limit,
                },
                config_create_params.ConfigCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Hyperdrive]._unwrapper,
            ),
            cast_to=cast(Type[Hyperdrive], ResultWrapper[Hyperdrive]),
        )

    async def update(
        self,
        hyperdrive_id: str,
        *,
        account_id: str,
        name: str,
        origin: config_update_params.Origin,
        caching: config_update_params.Caching | Omit = omit,
        mtls: config_update_params.MTLS | Omit = omit,
        origin_connection_limit: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Hyperdrive:
        """
        Updates and returns the specified Hyperdrive configuration.

        Args:
          account_id: Define configurations using a unique string identifier.

          hyperdrive_id: Define configurations using a unique string identifier.

          name: The name of the Hyperdrive configuration. Used to identify the configuration in
              the Cloudflare dashboard and API.

          mtls: mTLS configuration for the origin connection. Cannot be used with VPC Service
              origins; TLS must be managed on the VPC Service.

          origin_connection_limit: The (soft) maximum number of connections the Hyperdrive is allowed to make to
              the origin database.

              Maximum allowed: 20 for free tier accounts, 100 for paid tier accounts. If not
              specified, defaults to 20 for free tier and 60 for paid tier. Contact Cloudflare
              if you need a higher limit.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not hyperdrive_id:
            raise ValueError(f"Expected a non-empty value for `hyperdrive_id` but received {hyperdrive_id!r}")
        return await self._put(
            path_template(
                "/accounts/{account_id}/hyperdrive/configs/{hyperdrive_id}",
                account_id=account_id,
                hyperdrive_id=hyperdrive_id,
            ),
            body=await async_maybe_transform(
                {
                    "name": name,
                    "origin": origin,
                    "caching": caching,
                    "mtls": mtls,
                    "origin_connection_limit": origin_connection_limit,
                },
                config_update_params.ConfigUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Hyperdrive]._unwrapper,
            ),
            cast_to=cast(Type[Hyperdrive], ResultWrapper[Hyperdrive]),
        )

    def list(
        self,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[Hyperdrive, AsyncSinglePage[Hyperdrive]]:
        """
        Returns a list of Hyperdrives.

        Args:
          account_id: Define configurations using a unique string identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/hyperdrive/configs", account_id=account_id),
            page=AsyncSinglePage[Hyperdrive],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=Hyperdrive,
        )

    async def delete(
        self,
        hyperdrive_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Deletes the specified Hyperdrive.

        Args:
          account_id: Define configurations using a unique string identifier.

          hyperdrive_id: Define configurations using a unique string identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not hyperdrive_id:
            raise ValueError(f"Expected a non-empty value for `hyperdrive_id` but received {hyperdrive_id!r}")
        return await self._delete(
            path_template(
                "/accounts/{account_id}/hyperdrive/configs/{hyperdrive_id}",
                account_id=account_id,
                hyperdrive_id=hyperdrive_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[object]]._unwrapper,
            ),
            cast_to=cast(Type[object], ResultWrapper[object]),
        )

    async def edit(
        self,
        hyperdrive_id: str,
        *,
        account_id: str,
        caching: config_edit_params.Caching | Omit = omit,
        mtls: config_edit_params.MTLS | Omit = omit,
        name: str | Omit = omit,
        origin: config_edit_params.Origin | Omit = omit,
        origin_connection_limit: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Hyperdrive:
        """Patches and returns the specified Hyperdrive configuration.

        Custom caching
        settings are not kept if caching is disabled.

        Args:
          account_id: Define configurations using a unique string identifier.

          hyperdrive_id: Define configurations using a unique string identifier.

          mtls: mTLS configuration for the origin connection. Cannot be used with VPC Service
              origins; TLS must be managed on the VPC Service.

          name: The name of the Hyperdrive configuration. Used to identify the configuration in
              the Cloudflare dashboard and API.

          origin: Connect to a database through a Workers VPC Service. TLS settings (mTLS,
              sslmode) cannot be configured on the Hyperdrive when using a VPC Service origin;
              TLS must be managed on the VPC Service itself.

          origin_connection_limit: The (soft) maximum number of connections the Hyperdrive is allowed to make to
              the origin database.

              Maximum allowed: 20 for free tier accounts, 100 for paid tier accounts. If not
              specified, defaults to 20 for free tier and 60 for paid tier. Contact Cloudflare
              if you need a higher limit.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not hyperdrive_id:
            raise ValueError(f"Expected a non-empty value for `hyperdrive_id` but received {hyperdrive_id!r}")
        return await self._patch(
            path_template(
                "/accounts/{account_id}/hyperdrive/configs/{hyperdrive_id}",
                account_id=account_id,
                hyperdrive_id=hyperdrive_id,
            ),
            body=await async_maybe_transform(
                {
                    "caching": caching,
                    "mtls": mtls,
                    "name": name,
                    "origin": origin,
                    "origin_connection_limit": origin_connection_limit,
                },
                config_edit_params.ConfigEditParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Hyperdrive]._unwrapper,
            ),
            cast_to=cast(Type[Hyperdrive], ResultWrapper[Hyperdrive]),
        )

    async def get(
        self,
        hyperdrive_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Hyperdrive:
        """
        Returns the specified Hyperdrive configuration.

        Args:
          account_id: Define configurations using a unique string identifier.

          hyperdrive_id: Define configurations using a unique string identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not hyperdrive_id:
            raise ValueError(f"Expected a non-empty value for `hyperdrive_id` but received {hyperdrive_id!r}")
        return await self._get(
            path_template(
                "/accounts/{account_id}/hyperdrive/configs/{hyperdrive_id}",
                account_id=account_id,
                hyperdrive_id=hyperdrive_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Hyperdrive]._unwrapper,
            ),
            cast_to=cast(Type[Hyperdrive], ResultWrapper[Hyperdrive]),
        )


class ConfigsResourceWithRawResponse:
    def __init__(self, configs: ConfigsResource) -> None:
        self._configs = configs

        self.create = to_raw_response_wrapper(
            configs.create,
        )
        self.update = to_raw_response_wrapper(
            configs.update,
        )
        self.list = to_raw_response_wrapper(
            configs.list,
        )
        self.delete = to_raw_response_wrapper(
            configs.delete,
        )
        self.edit = to_raw_response_wrapper(
            configs.edit,
        )
        self.get = to_raw_response_wrapper(
            configs.get,
        )


class AsyncConfigsResourceWithRawResponse:
    def __init__(self, configs: AsyncConfigsResource) -> None:
        self._configs = configs

        self.create = async_to_raw_response_wrapper(
            configs.create,
        )
        self.update = async_to_raw_response_wrapper(
            configs.update,
        )
        self.list = async_to_raw_response_wrapper(
            configs.list,
        )
        self.delete = async_to_raw_response_wrapper(
            configs.delete,
        )
        self.edit = async_to_raw_response_wrapper(
            configs.edit,
        )
        self.get = async_to_raw_response_wrapper(
            configs.get,
        )


class ConfigsResourceWithStreamingResponse:
    def __init__(self, configs: ConfigsResource) -> None:
        self._configs = configs

        self.create = to_streamed_response_wrapper(
            configs.create,
        )
        self.update = to_streamed_response_wrapper(
            configs.update,
        )
        self.list = to_streamed_response_wrapper(
            configs.list,
        )
        self.delete = to_streamed_response_wrapper(
            configs.delete,
        )
        self.edit = to_streamed_response_wrapper(
            configs.edit,
        )
        self.get = to_streamed_response_wrapper(
            configs.get,
        )


class AsyncConfigsResourceWithStreamingResponse:
    def __init__(self, configs: AsyncConfigsResource) -> None:
        self._configs = configs

        self.create = async_to_streamed_response_wrapper(
            configs.create,
        )
        self.update = async_to_streamed_response_wrapper(
            configs.update,
        )
        self.list = async_to_streamed_response_wrapper(
            configs.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            configs.delete,
        )
        self.edit = async_to_streamed_response_wrapper(
            configs.edit,
        )
        self.get = async_to_streamed_response_wrapper(
            configs.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from ....._types import SequenceNotStr

__all__ = ["TargetBulkDeleteV2Params"]


class TargetBulkDeleteV2Params(TypedDict, total=False):
    account_id: Required[str]
    """Account identifier"""

    target_ids: Required[SequenceNotStr[str]]
    """List of target IDs to bulk delete"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .managed_transforms import (
    ManagedTransformsResource,
    AsyncManagedTransformsResource,
    ManagedTransformsResourceWithRawResponse,
    AsyncManagedTransformsResourceWithRawResponse,
    ManagedTransformsResourceWithStreamingResponse,
    AsyncManagedTransformsResourceWithStreamingResponse,
)

__all__ = [
    "ManagedTransformsResource",
    "AsyncManagedTransformsResource",
    "ManagedTransformsResourceWithRawResponse",
    "AsyncManagedTransformsResourceWithRawResponse",
    "ManagedTransformsResourceWithStreamingResponse",
    "AsyncManagedTransformsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

from ..._types import SequenceNotStr
from .logging_param import LoggingParam

__all__ = ["BlockRuleParam", "ActionParameters", "ActionParametersResponse", "ExposedCredentialCheck", "Ratelimit"]


class ActionParametersResponse(TypedDict, total=False):
    """The response to show when the block is applied."""

    content: Required[str]
    """The content to return."""

    content_type: Required[str]
    """The type of the content to return."""

    status_code: Required[int]
    """The status code to return."""


class ActionParameters(TypedDict, total=False):
    """The parameters configuring the rule's action."""

    response: ActionParametersResponse
    """The response to show when the block is applied."""


class ExposedCredentialCheck(TypedDict, total=False):
    """Configuration for exposed credential checking."""

    password_expression: Required[str]
    """An expression that selects the password used in the credentials check."""

    username_expression: Required[str]
    """An expression that selects the user ID used in the credentials check."""


class Ratelimit(TypedDict, total=False):
    """An object configuring the rule's rate limit behavior."""

    characteristics: Required[SequenceNotStr[str]]
    """
    Characteristics of the request on which the rate limit counter will be
    incremented.
    """

    period: Required[int]
    """Period in seconds over which the counter is being incremented."""

    counting_expression: str
    """An expression that defines when the rate limit counter should be incremented.

    It defaults to the same as the rule's expression.
    """

    mitigation_timeout: int
    """
    Period of time in seconds after which the action will be disabled following its
    first execution.
    """

    requests_per_period: int
    """
    The threshold of requests per period after which the action will be executed for
    the first time.
    """

    requests_to_origin: bool
    """Whether counting is only performed when an origin is reached."""

    score_per_period: int
    """
    The score threshold per period for which the action will be executed the first
    time.
    """

    score_response_header_name: str
    """
    A response header name provided by the origin, which contains the score to
    increment rate limit counter with.
    """


class BlockRuleParam(TypedDict, total=False):
    id: str
    """The unique ID of the rule."""

    action: Literal["block"]
    """The action to perform when the rule matches."""

    action_parameters: ActionParameters
    """The parameters configuring the rule's action."""

    description: str
    """An informative description of the rule."""

    enabled: bool
    """Whether the rule should be executed."""

    exposed_credential_check: ExposedCredentialCheck
    """Configuration for exposed credential checking."""

    expression: str
    """The expression defining which traffic will match the rule."""

    logging: LoggingParam
    """An object configuring the rule's logging behavior."""

    ratelimit: Ratelimit
    """An object configuring the rule's rate limit behavior."""

    ref: str
    """The reference of the rule (the rule's ID by default)."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ...._models import BaseModel

__all__ = ["TestDeleteResponse"]


class TestDeleteResponse(BaseModel):
    __test__ = False
    count: Optional[float] = None
    """Number of items affected."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .instances import (
    InstancesResource,
    AsyncInstancesResource,
    InstancesResourceWithRawResponse,
    AsyncInstancesResourceWithRawResponse,
    InstancesResourceWithStreamingResponse,
    AsyncInstancesResourceWithStreamingResponse,
)
from .namespaces import (
    NamespacesResource,
    AsyncNamespacesResource,
    NamespacesResourceWithRawResponse,
    AsyncNamespacesResourceWithRawResponse,
    NamespacesResourceWithStreamingResponse,
    AsyncNamespacesResourceWithStreamingResponse,
)

__all__ = [
    "InstancesResource",
    "AsyncInstancesResource",
    "InstancesResourceWithRawResponse",
    "AsyncInstancesResourceWithRawResponse",
    "InstancesResourceWithStreamingResponse",
    "AsyncInstancesResourceWithStreamingResponse",
    "NamespacesResource",
    "AsyncNamespacesResource",
    "NamespacesResourceWithRawResponse",
    "AsyncNamespacesResourceWithRawResponse",
    "NamespacesResourceWithStreamingResponse",
    "AsyncNamespacesResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["ObjectListParams"]


class ObjectListParams(TypedDict, total=False):
    account_id: Required[str]
    """Account ID."""

    cursor: str
    """Pagination cursor received from a previous List Objects call.

    Used to retrieve the next page of results.
    """

    delimiter: str
    """A single character used to group keys.

    All keys that contain the delimiter between the prefix and the first occurrence
    of the delimiter after the prefix are grouped under a single result element.
    """

    per_page: int
    """Maximum number of objects to return per page."""

    prefix: str
    """
    Restricts results to only those objects whose keys begin with the specified
    prefix.
    """

    start_after: str
    """
    Returns objects with keys that come after the specified key in lexicographic
    order.
    """

    jurisdiction: Annotated[Literal["default", "eu", "fedramp"], PropertyInfo(alias="cf-r2-jurisdiction")]
    """Jurisdiction where objects in this bucket are guaranteed to be stored."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union
from datetime import datetime
from typing_extensions import Literal, Annotated, TypedDict

from ....._types import SequenceNotStr
from ....._utils import PropertyInfo

__all__ = ["SummaryDurationParams"]


class SummaryDurationParams(TypedDict, total=False):
    continent: SequenceNotStr[str]
    """Filters results by continent.

    Specify a comma-separated list of alpha-2 codes. Prefix with `-` to exclude
    continents from results. For example, `-EU,NA` excludes results from EU, but
    includes results from NA.
    """

    date_end: Annotated[SequenceNotStr[Union[str, datetime]], PropertyInfo(alias="dateEnd", format="iso8601")]
    """End of the date range (inclusive)."""

    date_range: Annotated[SequenceNotStr[str], PropertyInfo(alias="dateRange")]
    """Filters results by date range.

    For example, use `7d` and `7dcontrol` to compare this week with the previous
    week. Use this parameter or set specific start and end dates (`dateStart` and
    `dateEnd` parameters).
    """

    date_start: Annotated[SequenceNotStr[Union[str, datetime]], PropertyInfo(alias="dateStart", format="iso8601")]
    """Start of the date range."""

    direction: Literal["ORIGIN", "TARGET"]
    """
    Specifies whether the `location` filter applies to the source or target
    location.
    """

    format: Literal["JSON", "CSV"]
    """Format in which results will be returned."""

    ip_version: Annotated[List[Literal["IPv4", "IPv6"]], PropertyInfo(alias="ipVersion")]
    """Filters results by IP version (Ipv4 vs. IPv6)."""

    location: SequenceNotStr[str]
    """Filters results by location.

    Specify a comma-separated list of alpha-2 codes. Prefix with `-` to exclude
    locations from results. For example, `-US,PT` excludes results from the US, but
    includes results from PT.
    """

    name: SequenceNotStr[str]
    """Array of names used to label the series in the response."""

    protocol: List[Literal["UDP", "TCP", "ICMP", "GRE"]]
    """Filters the results by layer 3/4 protocol."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, cast

import httpx

from ..._types import Body, Query, Headers, NoneType, NotGiven, not_given
from ..._utils import path_template, maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._wrappers import ResultWrapper
from ..._base_client import make_request_options
from ...types.organizations import organization_profile_update_params
from ...types.organizations.organization_profile_get_params import Result

__all__ = ["OrganizationProfileResource", "AsyncOrganizationProfileResource"]


class OrganizationProfileResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> OrganizationProfileResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return OrganizationProfileResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> OrganizationProfileResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return OrganizationProfileResourceWithStreamingResponse(self)

    def update(
        self,
        organization_id: str,
        *,
        business_address: str,
        business_email: str,
        business_name: str,
        business_phone: str,
        external_metadata: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Modify organization profile.

        (Currently in Closed Beta - see
        https://developers.cloudflare.com/fundamentals/organizations/)

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not organization_id:
            raise ValueError(f"Expected a non-empty value for `organization_id` but received {organization_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            path_template("/organizations/{organization_id}/profile", organization_id=organization_id),
            body=maybe_transform(
                {
                    "business_address": business_address,
                    "business_email": business_email,
                    "business_name": business_name,
                    "business_phone": business_phone,
                    "external_metadata": external_metadata,
                },
                organization_profile_update_params.OrganizationProfileUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def get(
        self,
        organization_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Result:
        """Get an organizations profile if it exists.

        (Currently in Closed Beta - see
        https://developers.cloudflare.com/fundamentals/organizations/)

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not organization_id:
            raise ValueError(f"Expected a non-empty value for `organization_id` but received {organization_id!r}")
        return self._get(
            path_template("/organizations/{organization_id}/profile", organization_id=organization_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Result]._unwrapper,
            ),
            cast_to=cast(Type[Result], ResultWrapper[Result]),
        )


class AsyncOrganizationProfileResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncOrganizationProfileResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncOrganizationProfileResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncOrganizationProfileResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncOrganizationProfileResourceWithStreamingResponse(self)

    async def update(
        self,
        organization_id: str,
        *,
        business_address: str,
        business_email: str,
        business_name: str,
        business_phone: str,
        external_metadata: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Modify organization profile.

        (Currently in Closed Beta - see
        https://developers.cloudflare.com/fundamentals/organizations/)

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not organization_id:
            raise ValueError(f"Expected a non-empty value for `organization_id` but received {organization_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._put(
            path_template("/organizations/{organization_id}/profile", organization_id=organization_id),
            body=await async_maybe_transform(
                {
                    "business_address": business_address,
                    "business_email": business_email,
                    "business_name": business_name,
                    "business_phone": business_phone,
                    "external_metadata": external_metadata,
                },
                organization_profile_update_params.OrganizationProfileUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def get(
        self,
        organization_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Result:
        """Get an organizations profile if it exists.

        (Currently in Closed Beta - see
        https://developers.cloudflare.com/fundamentals/organizations/)

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not organization_id:
            raise ValueError(f"Expected a non-empty value for `organization_id` but received {organization_id!r}")
        return await self._get(
            path_template("/organizations/{organization_id}/profile", organization_id=organization_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Result]._unwrapper,
            ),
            cast_to=cast(Type[Result], ResultWrapper[Result]),
        )


class OrganizationProfileResourceWithRawResponse:
    def __init__(self, organization_profile: OrganizationProfileResource) -> None:
        self._organization_profile = organization_profile

        self.update = to_raw_response_wrapper(
            organization_profile.update,
        )
        self.get = to_raw_response_wrapper(
            organization_profile.get,
        )


class AsyncOrganizationProfileResourceWithRawResponse:
    def __init__(self, organization_profile: AsyncOrganizationProfileResource) -> None:
        self._organization_profile = organization_profile

        self.update = async_to_raw_response_wrapper(
            organization_profile.update,
        )
        self.get = async_to_raw_response_wrapper(
            organization_profile.get,
        )


class OrganizationProfileResourceWithStreamingResponse:
    def __init__(self, organization_profile: OrganizationProfileResource) -> None:
        self._organization_profile = organization_profile

        self.update = to_streamed_response_wrapper(
            organization_profile.update,
        )
        self.get = to_streamed_response_wrapper(
            organization_profile.get,
        )


class AsyncOrganizationProfileResourceWithStreamingResponse:
    def __init__(self, organization_profile: AsyncOrganizationProfileResource) -> None:
        self._organization_profile = organization_profile

        self.update = async_to_streamed_response_wrapper(
            organization_profile.update,
        )
        self.get = async_to_streamed_response_wrapper(
            organization_profile.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, Optional, cast

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import path_template, maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._wrappers import ResultWrapper
from ...types.iam import sso_create_params, sso_update_params
from ...pagination import SyncSinglePage, AsyncSinglePage
from ..._base_client import AsyncPaginator, make_request_options
from ...types.iam.sso_get_response import SSOGetResponse
from ...types.iam.sso_list_response import SSOListResponse
from ...types.iam.sso_create_response import SSOCreateResponse
from ...types.iam.sso_delete_response import SSODeleteResponse
from ...types.iam.sso_update_response import SSOUpdateResponse
from ...types.iam.sso_begin_verification_response import SSOBeginVerificationResponse

__all__ = ["SSOResource", "AsyncSSOResource"]


class SSOResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SSOResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return SSOResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SSOResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return SSOResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        account_id: str,
        email_domain: str,
        begin_verification: bool | Omit = omit,
        use_fedramp_language: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[SSOCreateResponse]:
        """
        Initialize new SSO connector

        Args:
          account_id: Account identifier tag.

          email_domain: Email domain of the new SSO connector

          begin_verification: Begin the verification process after creation

          use_fedramp_language: Controls the display of FedRAMP language to the user during SSO login

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._post(
            path_template("/accounts/{account_id}/sso_connectors", account_id=account_id),
            body=maybe_transform(
                {
                    "email_domain": email_domain,
                    "begin_verification": begin_verification,
                    "use_fedramp_language": use_fedramp_language,
                },
                sso_create_params.SSOCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[SSOCreateResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[SSOCreateResponse]], ResultWrapper[SSOCreateResponse]),
        )

    def update(
        self,
        sso_connector_id: str,
        *,
        account_id: str,
        enabled: bool | Omit = omit,
        use_fedramp_language: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[SSOUpdateResponse]:
        """
        Update SSO connector state

        Args:
          account_id: Account identifier tag.

          sso_connector_id: SSO Connector identifier tag.

          enabled: SSO Connector enabled state

          use_fedramp_language: Controls the display of FedRAMP language to the user during SSO login

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not sso_connector_id:
            raise ValueError(f"Expected a non-empty value for `sso_connector_id` but received {sso_connector_id!r}")
        return self._patch(
            path_template(
                "/accounts/{account_id}/sso_connectors/{sso_connector_id}",
                account_id=account_id,
                sso_connector_id=sso_connector_id,
            ),
            body=maybe_transform(
                {
                    "enabled": enabled,
                    "use_fedramp_language": use_fedramp_language,
                },
                sso_update_params.SSOUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[SSOUpdateResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[SSOUpdateResponse]], ResultWrapper[SSOUpdateResponse]),
        )

    def list(
        self,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncSinglePage[SSOListResponse]:
        """
        Get all SSO connectors

        Args:
          account_id: Account identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/sso_connectors", account_id=account_id),
            page=SyncSinglePage[SSOListResponse],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=SSOListResponse,
        )

    def delete(
        self,
        sso_connector_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[SSODeleteResponse]:
        """
        Delete SSO connector

        Args:
          account_id: Account identifier tag.

          sso_connector_id: SSO Connector identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not sso_connector_id:
            raise ValueError(f"Expected a non-empty value for `sso_connector_id` but received {sso_connector_id!r}")
        return self._delete(
            path_template(
                "/accounts/{account_id}/sso_connectors/{sso_connector_id}",
                account_id=account_id,
                sso_connector_id=sso_connector_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[SSODeleteResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[SSODeleteResponse]], ResultWrapper[SSODeleteResponse]),
        )

    def begin_verification(
        self,
        sso_connector_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SSOBeginVerificationResponse:
        """
        Begin SSO connector verification

        Args:
          account_id: Account identifier tag.

          sso_connector_id: SSO Connector identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not sso_connector_id:
            raise ValueError(f"Expected a non-empty value for `sso_connector_id` but received {sso_connector_id!r}")
        return self._post(
            path_template(
                "/accounts/{account_id}/sso_connectors/{sso_connector_id}/begin_verification",
                account_id=account_id,
                sso_connector_id=sso_connector_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SSOBeginVerificationResponse,
        )

    def get(
        self,
        sso_connector_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[SSOGetResponse]:
        """
        Get single SSO connector

        Args:
          account_id: Account identifier tag.

          sso_connector_id: SSO Connector identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not sso_connector_id:
            raise ValueError(f"Expected a non-empty value for `sso_connector_id` but received {sso_connector_id!r}")
        return self._get(
            path_template(
                "/accounts/{account_id}/sso_connectors/{sso_connector_id}",
                account_id=account_id,
                sso_connector_id=sso_connector_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[SSOGetResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[SSOGetResponse]], ResultWrapper[SSOGetResponse]),
        )


class AsyncSSOResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSSOResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSSOResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSSOResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncSSOResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        account_id: str,
        email_domain: str,
        begin_verification: bool | Omit = omit,
        use_fedramp_language: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[SSOCreateResponse]:
        """
        Initialize new SSO connector

        Args:
          account_id: Account identifier tag.

          email_domain: Email domain of the new SSO connector

          begin_verification: Begin the verification process after creation

          use_fedramp_language: Controls the display of FedRAMP language to the user during SSO login

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._post(
            path_template("/accounts/{account_id}/sso_connectors", account_id=account_id),
            body=await async_maybe_transform(
                {
                    "email_domain": email_domain,
                    "begin_verification": begin_verification,
                    "use_fedramp_language": use_fedramp_language,
                },
                sso_create_params.SSOCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[SSOCreateResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[SSOCreateResponse]], ResultWrapper[SSOCreateResponse]),
        )

    async def update(
        self,
        sso_connector_id: str,
        *,
        account_id: str,
        enabled: bool | Omit = omit,
        use_fedramp_language: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[SSOUpdateResponse]:
        """
        Update SSO connector state

        Args:
          account_id: Account identifier tag.

          sso_connector_id: SSO Connector identifier tag.

          enabled: SSO Connector enabled state

          use_fedramp_language: Controls the display of FedRAMP language to the user during SSO login

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not sso_connector_id:
            raise ValueError(f"Expected a non-empty value for `sso_connector_id` but received {sso_connector_id!r}")
        return await self._patch(
            path_template(
                "/accounts/{account_id}/sso_connectors/{sso_connector_id}",
                account_id=account_id,
                sso_connector_id=sso_connector_id,
            ),
            body=await async_maybe_transform(
                {
                    "enabled": enabled,
                    "use_fedramp_language": use_fedramp_language,
                },
                sso_update_params.SSOUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[SSOUpdateResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[SSOUpdateResponse]], ResultWrapper[SSOUpdateResponse]),
        )

    def list(
        self,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[SSOListResponse, AsyncSinglePage[SSOListResponse]]:
        """
        Get all SSO connectors

        Args:
          account_id: Account identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/sso_connectors", account_id=account_id),
            page=AsyncSinglePage[SSOListResponse],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=SSOListResponse,
        )

    async def delete(
        self,
        sso_connector_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[SSODeleteResponse]:
        """
        Delete SSO connector

        Args:
          account_id: Account identifier tag.

          sso_connector_id: SSO Connector identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not sso_connector_id:
            raise ValueError(f"Expected a non-empty value for `sso_connector_id` but received {sso_connector_id!r}")
        return await self._delete(
            path_template(
                "/accounts/{account_id}/sso_connectors/{sso_connector_id}",
                account_id=account_id,
                sso_connector_id=sso_connector_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[SSODeleteResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[SSODeleteResponse]], ResultWrapper[SSODeleteResponse]),
        )

    async def begin_verification(
        self,
        sso_connector_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SSOBeginVerificationResponse:
        """
        Begin SSO connector verification

        Args:
          account_id: Account identifier tag.

          sso_connector_id: SSO Connector identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not sso_connector_id:
            raise ValueError(f"Expected a non-empty value for `sso_connector_id` but received {sso_connector_id!r}")
        return await self._post(
            path_template(
                "/accounts/{account_id}/sso_connectors/{sso_connector_id}/begin_verification",
                account_id=account_id,
                sso_connector_id=sso_connector_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SSOBeginVerificationResponse,
        )

    async def get(
        self,
        sso_connector_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[SSOGetResponse]:
        """
        Get single SSO connector

        Args:
          account_id: Account identifier tag.

          sso_connector_id: SSO Connector identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not sso_connector_id:
            raise ValueError(f"Expected a non-empty value for `sso_connector_id` but received {sso_connector_id!r}")
        return await self._get(
            path_template(
                "/accounts/{account_id}/sso_connectors/{sso_connector_id}",
                account_id=account_id,
                sso_connector_id=sso_connector_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[SSOGetResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[SSOGetResponse]], ResultWrapper[SSOGetResponse]),
        )


class SSOResourceWithRawResponse:
    def __init__(self, sso: SSOResource) -> None:
        self._sso = sso

        self.create = to_raw_response_wrapper(
            sso.create,
        )
        self.update = to_raw_response_wrapper(
            sso.update,
        )
        self.list = to_raw_response_wrapper(
            sso.list,
        )
        self.delete = to_raw_response_wrapper(
            sso.delete,
        )
        self.begin_verification = to_raw_response_wrapper(
            sso.begin_verification,
        )
        self.get = to_raw_response_wrapper(
            sso.get,
        )


class AsyncSSOResourceWithRawResponse:
    def __init__(self, sso: AsyncSSOResource) -> None:
        self._sso = sso

        self.create = async_to_raw_response_wrapper(
            sso.create,
        )
        self.update = async_to_raw_response_wrapper(
            sso.update,
        )
        self.list = async_to_raw_response_wrapper(
            sso.list,
        )
        self.delete = async_to_raw_response_wrapper(
            sso.delete,
        )
        self.begin_verification = async_to_raw_response_wrapper(
            sso.begin_verification,
        )
        self.get = async_to_raw_response_wrapper(
            sso.get,
        )


class SSOResourceWithStreamingResponse:
    def __init__(self, sso: SSOResource) -> None:
        self._sso = sso

        self.create = to_streamed_response_wrapper(
            sso.create,
        )
        self.update = to_streamed_response_wrapper(
            sso.update,
        )
        self.list = to_streamed_response_wrapper(
            sso.list,
        )
        self.delete = to_streamed_response_wrapper(
            sso.delete,
        )
        self.begin_verification = to_streamed_response_wrapper(
            sso.begin_verification,
        )
        self.get = to_streamed_response_wrapper(
            sso.get,
        )


class AsyncSSOResourceWithStreamingResponse:
    def __init__(self, sso: AsyncSSOResource) -> None:
        self._sso = sso

        self.create = async_to_streamed_response_wrapper(
            sso.create,
        )
        self.update = async_to_streamed_response_wrapper(
            sso.update,
        )
        self.list = async_to_streamed_response_wrapper(
            sso.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            sso.delete,
        )
        self.begin_verification = async_to_streamed_response_wrapper(
            sso.begin_verification,
        )
        self.get = async_to_streamed_response_wrapper(
            sso.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime
from typing_extensions import Literal

from .phase import Phase
from .logging import Logging
from ..._models import BaseModel

__all__ = ["SkipRule", "ActionParameters", "ExposedCredentialCheck", "Ratelimit"]


class ActionParameters(BaseModel):
    """The parameters configuring the rule's action."""

    phase: Optional[Literal["current"]] = None
    """A phase to skip the execution of.

    This option is only compatible with the products option.
    """

    phases: Optional[List[Phase]] = None
    """A list of phases to skip the execution of.

    This option is incompatible with the rulesets option.
    """

    products: Optional[List[Literal["bic", "hot", "rateLimit", "securityLevel", "uaBlock", "waf", "zoneLockdown"]]] = (
        None
    )
    """A list of legacy security products to skip the execution of."""

    rules: Optional[Dict[str, List[str]]] = None
    """
    A mapping of ruleset IDs to a list of rule IDs in that ruleset to skip the
    execution of. This option is incompatible with the ruleset option.
    """

    ruleset: Optional[Literal["current"]] = None
    """A ruleset to skip the execution of.

    This option is incompatible with the rulesets option.
    """

    rulesets: Optional[List[str]] = None
    """A list of ruleset IDs to skip the execution of.

    This option is incompatible with the ruleset and phases options.
    """


class ExposedCredentialCheck(BaseModel):
    """Configuration for exposed credential checking."""

    password_expression: str
    """An expression that selects the password used in the credentials check."""

    username_expression: str
    """An expression that selects the user ID used in the credentials check."""


class Ratelimit(BaseModel):
    """An object configuring the rule's rate limit behavior."""

    characteristics: List[str]
    """
    Characteristics of the request on which the rate limit counter will be
    incremented.
    """

    period: int
    """Period in seconds over which the counter is being incremented."""

    counting_expression: Optional[str] = None
    """An expression that defines when the rate limit counter should be incremented.

    It defaults to the same as the rule's expression.
    """

    mitigation_timeout: Optional[int] = None
    """
    Period of time in seconds after which the action will be disabled following its
    first execution.
    """

    requests_per_period: Optional[int] = None
    """
    The threshold of requests per period after which the action will be executed for
    the first time.
    """

    requests_to_origin: Optional[bool] = None
    """Whether counting is only performed when an origin is reached."""

    score_per_period: Optional[int] = None
    """
    The score threshold per period for which the action will be executed the first
    time.
    """

    score_response_header_name: Optional[str] = None
    """
    A response header name provided by the origin, which contains the score to
    increment rate limit counter with.
    """


class SkipRule(BaseModel):
    last_updated: datetime
    """The timestamp of when the rule was last modified."""

    version: str
    """The version of the rule."""

    id: Optional[str] = None
    """The unique ID of the rule."""

    action: Optional[Literal["skip"]] = None
    """The action to perform when the rule matches."""

    action_parameters: Optional[ActionParameters] = None
    """The parameters configuring the rule's action."""

    categories: Optional[List[str]] = None
    """The categories of the rule."""

    description: Optional[str] = None
    """An informative description of the rule."""

    enabled: Optional[bool] = None
    """Whether the rule should be executed."""

    exposed_credential_check: Optional[ExposedCredentialCheck] = None
    """Configuration for exposed credential checking."""

    expression: Optional[str] = None
    """The expression defining which traffic will match the rule."""

    logging: Optional[Logging] = None
    """An object configuring the rule's logging behavior."""

    ratelimit: Optional[Ratelimit] = None
    """An object configuring the rule's rate limit behavior."""

    ref: Optional[str] = None
    """The reference of the rule (the rule's ID by default)."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .config_get_params import ConfigGetParams as ConfigGetParams
from .config_get_response import ConfigGetResponse as ConfigGetResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .audit_list_params import AuditListParams as AuditListParams
from .audit_list_response import AuditListResponse as AuditListResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["CustomNameserverUpdateParams"]


class CustomNameserverUpdateParams(TypedDict, total=False):
    zone_id: Required[str]
    """Identifier."""

    enabled: bool
    """Whether zone uses account-level custom nameservers."""

    ns_set: float
    """The number of the name server set to assign to the zone."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = [
    "R2DataCatalogListResponse",
    "Warehouse",
    "WarehouseMaintenanceConfig",
    "WarehouseMaintenanceConfigCompaction",
    "WarehouseMaintenanceConfigSnapshotExpiration",
]


class WarehouseMaintenanceConfigCompaction(BaseModel):
    """Configures compaction for catalog maintenance."""

    state: Literal["enabled", "disabled"]
    """Specifies the state of maintenance operations."""

    target_size_mb: Literal["64", "128", "256", "512"]
    """Sets the target file size for compaction in megabytes. Defaults to "128"."""


class WarehouseMaintenanceConfigSnapshotExpiration(BaseModel):
    """Configures snapshot expiration settings."""

    max_snapshot_age: str
    """Specifies the maximum age for snapshots.

    The system deletes snapshots older than this age. Format: <number><unit> where
    unit is d (days), h (hours), m (minutes), or s (seconds). Examples: "7d" (7
    days), "48h" (48 hours), "2880m" (2,880 minutes). Defaults to "7d".
    """

    min_snapshots_to_keep: int
    """Specifies the minimum number of snapshots to retain. Defaults to 100."""

    state: Literal["enabled", "disabled"]
    """Specifies the state of maintenance operations."""


class WarehouseMaintenanceConfig(BaseModel):
    """Configures maintenance for the catalog."""

    compaction: Optional[WarehouseMaintenanceConfigCompaction] = None
    """Configures compaction for catalog maintenance."""

    snapshot_expiration: Optional[WarehouseMaintenanceConfigSnapshotExpiration] = None
    """Configures snapshot expiration settings."""


class Warehouse(BaseModel):
    """Contains R2 Data Catalog information."""

    id: str
    """Use this to uniquely identify the catalog."""

    bucket: str
    """Specifies the associated R2 bucket name."""

    name: str
    """Specifies the catalog name (generated from account and bucket name)."""

    status: Literal["active", "inactive"]
    """Indicates the status of the catalog."""

    credential_status: Optional[Literal["present", "absent"]] = None
    """Shows the credential configuration status."""

    maintenance_config: Optional[WarehouseMaintenanceConfig] = None
    """Configures maintenance for the catalog."""


class R2DataCatalogListResponse(BaseModel):
    """Contains the list of catalogs."""

    warehouses: List[Warehouse]
    """Lists catalogs in the account."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Union, Optional
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = [
    "PresetUpdateResponse",
    "Data",
    "DataConfig",
    "DataConfigMaxVideoStreams",
    "DataConfigMedia",
    "DataConfigMediaScreenshare",
    "DataConfigMediaVideo",
    "DataConfigMediaAudio",
    "DataUI",
    "DataUIDesignTokens",
    "DataUIDesignTokensColors",
    "DataUIDesignTokensColorsBackground",
    "DataUIDesignTokensColorsBrand",
    "DataPermissions",
    "DataPermissionsChat",
    "DataPermissionsChatPrivate",
    "DataPermissionsChatPublic",
    "DataPermissionsConnectedMeetings",
    "DataPermissionsMedia",
    "DataPermissionsMediaAudio",
    "DataPermissionsMediaScreenshare",
    "DataPermissionsMediaVideo",
    "DataPermissionsPlugins",
    "DataPermissionsPluginsConfig",
    "DataPermissionsPluginsConfigUnionMember1",
    "DataPermissionsPolls",
]


class DataConfigMaxVideoStreams(BaseModel):
    """Maximum number of streams that are visible on a device"""

    desktop: int
    """Maximum number of video streams visible on desktop devices"""

    mobile: int
    """Maximum number of streams visible on mobile devices"""


class DataConfigMediaScreenshare(BaseModel):
    """Configuration options for participant screen shares"""

    frame_rate: int
    """Frame rate of screen share"""

    quality: Literal["hd", "vga", "qvga"]
    """Quality of screen share"""


class DataConfigMediaVideo(BaseModel):
    """Configuration options for participant videos"""

    frame_rate: int
    """Frame rate of participants' video"""

    quality: Literal["hd", "vga", "qvga"]
    """Video quality of participants"""


class DataConfigMediaAudio(BaseModel):
    """Control options for Audio quality."""

    enable_high_bitrate: Optional[bool] = None
    """Enable High Quality Audio for your meetings"""

    enable_stereo: Optional[bool] = None
    """Enable Stereo for your meetings"""


class DataConfigMedia(BaseModel):
    """Media configuration options. eg: Video quality"""

    screenshare: DataConfigMediaScreenshare
    """Configuration options for participant screen shares"""

    video: DataConfigMediaVideo
    """Configuration options for participant videos"""

    audio: Optional[DataConfigMediaAudio] = None
    """Control options for Audio quality."""


class DataConfig(BaseModel):
    max_screenshare_count: int
    """Maximum number of screen shares that can be active at a given time"""

    max_video_streams: DataConfigMaxVideoStreams
    """Maximum number of streams that are visible on a device"""

    media: DataConfigMedia
    """Media configuration options. eg: Video quality"""

    view_type: Literal["GROUP_CALL", "WEBINAR", "AUDIO_ROOM"]
    """Type of the meeting"""


class DataUIDesignTokensColorsBackground(BaseModel):
    api_1000: str = FieldInfo(alias="1000")

    api_600: str = FieldInfo(alias="600")

    api_700: str = FieldInfo(alias="700")

    api_800: str = FieldInfo(alias="800")

    api_900: str = FieldInfo(alias="900")


class DataUIDesignTokensColorsBrand(BaseModel):
    api_300: str = FieldInfo(alias="300")

    api_400: str = FieldInfo(alias="400")

    api_500: str = FieldInfo(alias="500")

    api_600: str = FieldInfo(alias="600")

    api_700: str = FieldInfo(alias="700")


class DataUIDesignTokensColors(BaseModel):
    background: DataUIDesignTokensColorsBackground

    brand: DataUIDesignTokensColorsBrand

    danger: str

    success: str

    text: str

    text_on_brand: str

    video_bg: str

    warning: str


class DataUIDesignTokens(BaseModel):
    border_radius: Literal["rounded"]

    border_width: Literal["thin"]

    colors: DataUIDesignTokensColors

    logo: str

    spacing_base: float

    theme: Literal["dark"]


class DataUI(BaseModel):
    design_tokens: DataUIDesignTokens

    config_diff: Optional[object] = None


class DataPermissionsChatPrivate(BaseModel):
    can_receive: bool

    can_send: bool

    files: bool

    text: bool


class DataPermissionsChatPublic(BaseModel):
    can_send: bool
    """Can send messages in general"""

    files: bool
    """Can send file messages"""

    text: bool
    """Can send text messages"""


class DataPermissionsChat(BaseModel):
    """Chat permissions"""

    private: DataPermissionsChatPrivate

    public: DataPermissionsChatPublic


class DataPermissionsConnectedMeetings(BaseModel):
    can_alter_connected_meetings: bool

    can_switch_connected_meetings: bool

    can_switch_to_parent_meeting: bool


class DataPermissionsMediaAudio(BaseModel):
    """Audio permissions"""

    can_produce: Literal["ALLOWED", "NOT_ALLOWED", "CAN_REQUEST"]
    """Can produce audio"""


class DataPermissionsMediaScreenshare(BaseModel):
    """Screenshare permissions"""

    can_produce: Literal["ALLOWED", "NOT_ALLOWED", "CAN_REQUEST"]
    """Can produce screen share video"""


class DataPermissionsMediaVideo(BaseModel):
    """Video permissions"""

    can_produce: Literal["ALLOWED", "NOT_ALLOWED", "CAN_REQUEST"]
    """Can produce video"""


class DataPermissionsMedia(BaseModel):
    """Media permissions"""

    audio: DataPermissionsMediaAudio
    """Audio permissions"""

    screenshare: DataPermissionsMediaScreenshare
    """Screenshare permissions"""

    video: DataPermissionsMediaVideo
    """Video permissions"""


class DataPermissionsPluginsConfigUnionMember1(BaseModel):
    access_control: Literal["FULL_ACCESS", "VIEW_ONLY"]

    handles_view_only: bool


DataPermissionsPluginsConfig: TypeAlias = Union[str, DataPermissionsPluginsConfigUnionMember1]


class DataPermissionsPlugins(BaseModel):
    """Plugin permissions"""

    can_close: bool
    """Can close plugins that are already open"""

    can_edit_config: bool
    """Can edit plugin config"""

    can_start: bool
    """Can start plugins"""

    config: DataPermissionsPluginsConfig


class DataPermissionsPolls(BaseModel):
    """Poll permissions"""

    can_create: bool
    """Can create polls"""

    can_view: bool
    """Can view polls"""

    can_vote: bool
    """Can vote on polls"""


class DataPermissions(BaseModel):
    accept_waiting_requests: bool
    """Whether this participant can accept waiting requests"""

    can_accept_production_requests: bool

    can_change_participant_permissions: bool

    can_edit_display_name: bool

    can_livestream: bool

    can_record: bool

    can_spotlight: bool

    chat: DataPermissionsChat
    """Chat permissions"""

    connected_meetings: DataPermissionsConnectedMeetings

    disable_participant_audio: bool

    disable_participant_screensharing: bool

    disable_participant_video: bool

    hidden_participant: bool
    """Whether this participant is visible to others or not"""

    kick_participant: bool

    media: DataPermissionsMedia
    """Media permissions"""

    pin_participant: bool

    plugins: DataPermissionsPlugins
    """Plugin permissions"""

    polls: DataPermissionsPolls
    """Poll permissions"""

    recorder_type: Literal["RECORDER", "LIVESTREAMER", "NONE"]
    """Type of the recording peer"""

    show_participant_list: bool

    waiting_room_type: Literal["SKIP", "ON_PRIVILEGED_USER_ENTRY", "SKIP_ON_ACCEPT"]
    """Waiting room type"""

    is_recorder: Optional[bool] = None


class Data(BaseModel):
    """Data returned by the operation"""

    id: str
    """ID of the preset"""

    config: DataConfig

    name: str
    """Name of the preset"""

    ui: DataUI

    permissions: Optional[DataPermissions] = None


class PresetUpdateResponse(BaseModel):
    data: Data
    """Data returned by the operation"""

    success: bool
    """Success status of the operation"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .acm import (
    ACMResource,
    AsyncACMResource,
    ACMResourceWithRawResponse,
    AsyncACMResourceWithRawResponse,
    ACMResourceWithStreamingResponse,
    AsyncACMResourceWithStreamingResponse,
)
from .total_tls import (
    TotalTLSResource,
    AsyncTotalTLSResource,
    TotalTLSResourceWithRawResponse,
    AsyncTotalTLSResourceWithRawResponse,
    TotalTLSResourceWithStreamingResponse,
    AsyncTotalTLSResourceWithStreamingResponse,
)
from .custom_trust_store import (
    CustomTrustStoreResource,
    AsyncCustomTrustStoreResource,
    CustomTrustStoreResourceWithRawResponse,
    AsyncCustomTrustStoreResourceWithRawResponse,
    CustomTrustStoreResourceWithStreamingResponse,
    AsyncCustomTrustStoreResourceWithStreamingResponse,
)

__all__ = [
    "TotalTLSResource",
    "AsyncTotalTLSResource",
    "TotalTLSResourceWithRawResponse",
    "AsyncTotalTLSResourceWithRawResponse",
    "TotalTLSResourceWithStreamingResponse",
    "AsyncTotalTLSResourceWithStreamingResponse",
    "CustomTrustStoreResource",
    "AsyncCustomTrustStoreResource",
    "CustomTrustStoreResourceWithRawResponse",
    "AsyncCustomTrustStoreResourceWithRawResponse",
    "CustomTrustStoreResourceWithStreamingResponse",
    "AsyncCustomTrustStoreResourceWithStreamingResponse",
    "ACMResource",
    "AsyncACMResource",
    "ACMResourceWithRawResponse",
    "AsyncACMResourceWithRawResponse",
    "ACMResourceWithStreamingResponse",
    "AsyncACMResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Union, Optional
from typing_extensions import Literal, Annotated, TypeAlias

from pydantic import Field as FieldInfo

from ..._utils import PropertyInfo
from ..._models import BaseModel
from .neo_event import NeoEvent
from .button_text_translation import ButtonTextTranslation

__all__ = [
    "Configuration",
    "Settings",
    "SettingsContextEnricher",
    "Tools",
    "ToolsZarazManagedComponent",
    "ToolsWorker",
    "ToolsWorkerWorker",
    "Triggers",
    "TriggersExcludeRule",
    "TriggersExcludeRuleZarazLoadRule",
    "TriggersExcludeRuleZarazClickListenerRule",
    "TriggersExcludeRuleZarazClickListenerRuleSettings",
    "TriggersExcludeRuleZarazTimerRule",
    "TriggersExcludeRuleZarazTimerRuleSettings",
    "TriggersExcludeRuleZarazFormSubmissionRule",
    "TriggersExcludeRuleZarazFormSubmissionRuleSettings",
    "TriggersExcludeRuleZarazVariableMatchRule",
    "TriggersExcludeRuleZarazVariableMatchRuleSettings",
    "TriggersExcludeRuleZarazScrollDepthRule",
    "TriggersExcludeRuleZarazScrollDepthRuleSettings",
    "TriggersExcludeRuleZarazElementVisibilityRule",
    "TriggersExcludeRuleZarazElementVisibilityRuleSettings",
    "TriggersLoadRule",
    "TriggersLoadRuleZarazLoadRule",
    "TriggersLoadRuleZarazClickListenerRule",
    "TriggersLoadRuleZarazClickListenerRuleSettings",
    "TriggersLoadRuleZarazTimerRule",
    "TriggersLoadRuleZarazTimerRuleSettings",
    "TriggersLoadRuleZarazFormSubmissionRule",
    "TriggersLoadRuleZarazFormSubmissionRuleSettings",
    "TriggersLoadRuleZarazVariableMatchRule",
    "TriggersLoadRuleZarazVariableMatchRuleSettings",
    "TriggersLoadRuleZarazScrollDepthRule",
    "TriggersLoadRuleZarazScrollDepthRuleSettings",
    "TriggersLoadRuleZarazElementVisibilityRule",
    "TriggersLoadRuleZarazElementVisibilityRuleSettings",
    "Variables",
    "VariablesZarazStringVariable",
    "VariablesZarazSecretVariable",
    "VariablesZarazWorkerVariable",
    "VariablesZarazWorkerVariableValue",
    "Analytics",
    "Consent",
    "ConsentPurposes",
    "ConsentPurposesWithTranslations",
]


class SettingsContextEnricher(BaseModel):
    """Details of the worker that receives and edits Zaraz Context object."""

    escaped_worker_name: str = FieldInfo(alias="escapedWorkerName")

    worker_tag: str = FieldInfo(alias="workerTag")


class Settings(BaseModel):
    """General Zaraz settings."""

    auto_inject_script: bool = FieldInfo(alias="autoInjectScript")
    """Automatic injection of Zaraz scripts enabled."""

    context_enricher: Optional[SettingsContextEnricher] = FieldInfo(alias="contextEnricher", default=None)
    """Details of the worker that receives and edits Zaraz Context object."""

    cookie_domain: Optional[str] = FieldInfo(alias="cookieDomain", default=None)
    """The domain Zaraz will use for writing and reading its cookies."""

    ecommerce: Optional[bool] = None
    """Ecommerce API enabled."""

    events_api_path: Optional[str] = FieldInfo(alias="eventsApiPath", default=None)
    """Custom endpoint for server-side track events."""

    hide_external_referer: Optional[bool] = FieldInfo(alias="hideExternalReferer", default=None)
    """Hiding external referrer URL enabled."""

    hide_ip_address: Optional[bool] = FieldInfo(alias="hideIPAddress", default=None)
    """Trimming IP address enabled."""

    hide_query_params: Optional[bool] = FieldInfo(alias="hideQueryParams", default=None)
    """Removing URL query params enabled."""

    hide_user_agent: Optional[bool] = FieldInfo(alias="hideUserAgent", default=None)
    """Removing sensitive data from User Agent string enabled."""

    init_path: Optional[str] = FieldInfo(alias="initPath", default=None)
    """Custom endpoint for Zaraz init script."""

    inject_iframes: Optional[bool] = FieldInfo(alias="injectIframes", default=None)
    """Injection of Zaraz scripts into iframes enabled."""

    mc_root_path: Optional[str] = FieldInfo(alias="mcRootPath", default=None)
    """Custom path for Managed Components server functionalities."""

    script_path: Optional[str] = FieldInfo(alias="scriptPath", default=None)
    """Custom endpoint for Zaraz main script."""

    track_path: Optional[str] = FieldInfo(alias="trackPath", default=None)
    """Custom endpoint for Zaraz tracking requests."""


class ToolsZarazManagedComponent(BaseModel):
    blocking_triggers: List[str] = FieldInfo(alias="blockingTriggers")
    """List of blocking trigger IDs."""

    component: str
    """Tool's internal name."""

    default_fields: Dict[str, Union[str, bool]] = FieldInfo(alias="defaultFields")
    """Default fields for tool's actions."""

    enabled: bool
    """Whether tool is enabled."""

    name: str
    """Tool's name defined by the user."""

    permissions: List[str]
    """List of permissions granted to the component."""

    settings: Dict[str, Union[str, bool]]
    """Tool's settings."""

    type: Literal["component"]

    actions: Optional[Dict[str, NeoEvent]] = None
    """Actions configured on a tool. Either this or neoEvents field is required."""

    default_purpose: Optional[str] = FieldInfo(alias="defaultPurpose", default=None)
    """Default consent purpose ID."""

    neo_events: Optional[List[NeoEvent]] = FieldInfo(alias="neoEvents", default=None)
    """DEPRECATED - List of actions configured on a tool.

    Either this or actions field is required. If both are present, actions field
    will take precedence.
    """

    vendor_name: Optional[str] = FieldInfo(alias="vendorName", default=None)
    """
    Vendor name for TCF compliant consent modal, required for Custom Managed
    Components and Custom HTML tool with a defaultPurpose assigned.
    """

    vendor_policy_url: Optional[str] = FieldInfo(alias="vendorPolicyUrl", default=None)
    """
    Vendor's Privacy Policy URL for TCF compliant consent modal, required for Custom
    Managed Components and Custom HTML tool with a defaultPurpose assigned.
    """


class ToolsWorkerWorker(BaseModel):
    """Cloudflare worker that acts as a managed component."""

    escaped_worker_name: str = FieldInfo(alias="escapedWorkerName")

    worker_tag: str = FieldInfo(alias="workerTag")


class ToolsWorker(BaseModel):
    blocking_triggers: List[str] = FieldInfo(alias="blockingTriggers")
    """List of blocking trigger IDs."""

    component: str
    """Tool's internal name."""

    default_fields: Dict[str, Union[str, bool]] = FieldInfo(alias="defaultFields")
    """Default fields for tool's actions."""

    enabled: bool
    """Whether tool is enabled."""

    name: str
    """Tool's name defined by the user."""

    permissions: List[str]
    """List of permissions granted to the component."""

    settings: Dict[str, Union[str, bool]]
    """Tool's settings."""

    type: Literal["custom-mc"]

    worker: ToolsWorkerWorker
    """Cloudflare worker that acts as a managed component."""

    actions: Optional[Dict[str, NeoEvent]] = None
    """Actions configured on a tool. Either this or neoEvents field is required."""

    default_purpose: Optional[str] = FieldInfo(alias="defaultPurpose", default=None)
    """Default consent purpose ID."""

    neo_events: Optional[List[NeoEvent]] = FieldInfo(alias="neoEvents", default=None)
    """DEPRECATED - List of actions configured on a tool.

    Either this or actions field is required. If both are present, actions field
    will take precedence.
    """

    vendor_name: Optional[str] = FieldInfo(alias="vendorName", default=None)
    """
    Vendor name for TCF compliant consent modal, required for Custom Managed
    Components and Custom HTML tool with a defaultPurpose assigned.
    """

    vendor_policy_url: Optional[str] = FieldInfo(alias="vendorPolicyUrl", default=None)
    """
    Vendor's Privacy Policy URL for TCF compliant consent modal, required for Custom
    Managed Components and Custom HTML tool with a defaultPurpose assigned.
    """


Tools: TypeAlias = Union[ToolsZarazManagedComponent, ToolsWorker]


class TriggersExcludeRuleZarazLoadRule(BaseModel):
    id: str

    match: str

    op: Literal[
        "CONTAINS",
        "EQUALS",
        "STARTS_WITH",
        "ENDS_WITH",
        "MATCH_REGEX",
        "NOT_MATCH_REGEX",
        "GREATER_THAN",
        "GREATER_THAN_OR_EQUAL",
        "LESS_THAN",
        "LESS_THAN_OR_EQUAL",
    ]

    value: str


class TriggersExcludeRuleZarazClickListenerRuleSettings(BaseModel):
    selector: str

    type: Literal["xpath", "css"]

    wait_for_tags: int = FieldInfo(alias="waitForTags")


class TriggersExcludeRuleZarazClickListenerRule(BaseModel):
    id: str

    action: Literal["clickListener"]

    settings: TriggersExcludeRuleZarazClickListenerRuleSettings


class TriggersExcludeRuleZarazTimerRuleSettings(BaseModel):
    interval: int

    limit: int


class TriggersExcludeRuleZarazTimerRule(BaseModel):
    id: str

    action: Literal["timer"]

    settings: TriggersExcludeRuleZarazTimerRuleSettings


class TriggersExcludeRuleZarazFormSubmissionRuleSettings(BaseModel):
    selector: str

    validate_: bool = FieldInfo(alias="validate")


class TriggersExcludeRuleZarazFormSubmissionRule(BaseModel):
    id: str

    action: Literal["formSubmission"]

    settings: TriggersExcludeRuleZarazFormSubmissionRuleSettings


class TriggersExcludeRuleZarazVariableMatchRuleSettings(BaseModel):
    match: str

    variable: str


class TriggersExcludeRuleZarazVariableMatchRule(BaseModel):
    id: str

    action: Literal["variableMatch"]

    settings: TriggersExcludeRuleZarazVariableMatchRuleSettings


class TriggersExcludeRuleZarazScrollDepthRuleSettings(BaseModel):
    positions: str


class TriggersExcludeRuleZarazScrollDepthRule(BaseModel):
    id: str

    action: Literal["scrollDepth"]

    settings: TriggersExcludeRuleZarazScrollDepthRuleSettings


class TriggersExcludeRuleZarazElementVisibilityRuleSettings(BaseModel):
    selector: str


class TriggersExcludeRuleZarazElementVisibilityRule(BaseModel):
    id: str

    action: Literal["elementVisibility"]

    settings: TriggersExcludeRuleZarazElementVisibilityRuleSettings


TriggersExcludeRule: TypeAlias = Union[
    TriggersExcludeRuleZarazLoadRule,
    TriggersExcludeRuleZarazClickListenerRule,
    TriggersExcludeRuleZarazTimerRule,
    TriggersExcludeRuleZarazFormSubmissionRule,
    TriggersExcludeRuleZarazVariableMatchRule,
    TriggersExcludeRuleZarazScrollDepthRule,
    TriggersExcludeRuleZarazElementVisibilityRule,
]


class TriggersLoadRuleZarazLoadRule(BaseModel):
    id: str

    match: str

    op: Literal[
        "CONTAINS",
        "EQUALS",
        "STARTS_WITH",
        "ENDS_WITH",
        "MATCH_REGEX",
        "NOT_MATCH_REGEX",
        "GREATER_THAN",
        "GREATER_THAN_OR_EQUAL",
        "LESS_THAN",
        "LESS_THAN_OR_EQUAL",
    ]

    value: str


class TriggersLoadRuleZarazClickListenerRuleSettings(BaseModel):
    selector: str

    type: Literal["xpath", "css"]

    wait_for_tags: int = FieldInfo(alias="waitForTags")


class TriggersLoadRuleZarazClickListenerRule(BaseModel):
    id: str

    action: Literal["clickListener"]

    settings: TriggersLoadRuleZarazClickListenerRuleSettings


class TriggersLoadRuleZarazTimerRuleSettings(BaseModel):
    interval: int

    limit: int


class TriggersLoadRuleZarazTimerRule(BaseModel):
    id: str

    action: Literal["timer"]

    settings: TriggersLoadRuleZarazTimerRuleSettings


class TriggersLoadRuleZarazFormSubmissionRuleSettings(BaseModel):
    selector: str

    validate_: bool = FieldInfo(alias="validate")


class TriggersLoadRuleZarazFormSubmissionRule(BaseModel):
    id: str

    action: Literal["formSubmission"]

    settings: TriggersLoadRuleZarazFormSubmissionRuleSettings


class TriggersLoadRuleZarazVariableMatchRuleSettings(BaseModel):
    match: str

    variable: str


class TriggersLoadRuleZarazVariableMatchRule(BaseModel):
    id: str

    action: Literal["variableMatch"]

    settings: TriggersLoadRuleZarazVariableMatchRuleSettings


class TriggersLoadRuleZarazScrollDepthRuleSettings(BaseModel):
    positions: str


class TriggersLoadRuleZarazScrollDepthRule(BaseModel):
    id: str

    action: Literal["scrollDepth"]

    settings: TriggersLoadRuleZarazScrollDepthRuleSettings


class TriggersLoadRuleZarazElementVisibilityRuleSettings(BaseModel):
    selector: str


class TriggersLoadRuleZarazElementVisibilityRule(BaseModel):
    id: str

    action: Literal["elementVisibility"]

    settings: TriggersLoadRuleZarazElementVisibilityRuleSettings


TriggersLoadRule: TypeAlias = Union[
    TriggersLoadRuleZarazLoadRule,
    TriggersLoadRuleZarazClickListenerRule,
    TriggersLoadRuleZarazTimerRule,
    TriggersLoadRuleZarazFormSubmissionRule,
    TriggersLoadRuleZarazVariableMatchRule,
    TriggersLoadRuleZarazScrollDepthRule,
    TriggersLoadRuleZarazElementVisibilityRule,
]


class Triggers(BaseModel):
    exclude_rules: List[TriggersExcludeRule] = FieldInfo(alias="excludeRules")
    """Rules defining when the trigger is not fired."""

    load_rules: List[TriggersLoadRule] = FieldInfo(alias="loadRules")
    """Rules defining when the trigger is fired."""

    name: str
    """Trigger name."""

    description: Optional[str] = None
    """Trigger description."""

    system: Optional[Literal["pageload"]] = None


class VariablesZarazStringVariable(BaseModel):
    name: str

    type: Literal["string"]

    value: str


class VariablesZarazSecretVariable(BaseModel):
    name: str

    type: Literal["secret"]

    value: str


class VariablesZarazWorkerVariableValue(BaseModel):
    escaped_worker_name: str = FieldInfo(alias="escapedWorkerName")

    worker_tag: str = FieldInfo(alias="workerTag")


class VariablesZarazWorkerVariable(BaseModel):
    name: str

    type: Literal["worker"]

    value: VariablesZarazWorkerVariableValue


Variables: TypeAlias = Annotated[
    Union[VariablesZarazStringVariable, VariablesZarazSecretVariable, VariablesZarazWorkerVariable],
    PropertyInfo(discriminator="type"),
]


class Analytics(BaseModel):
    """Cloudflare Monitoring settings."""

    default_purpose: Optional[str] = FieldInfo(alias="defaultPurpose", default=None)
    """Consent purpose assigned to Monitoring."""

    enabled: Optional[bool] = None
    """Whether Advanced Monitoring reports are enabled."""

    session_exp_time: Optional[int] = FieldInfo(alias="sessionExpTime", default=None)
    """Session expiration time (seconds)."""


class ConsentPurposes(BaseModel):
    description: str

    name: str


class ConsentPurposesWithTranslations(BaseModel):
    description: Dict[str, str]
    """Object where keys are language codes."""

    name: Dict[str, str]
    """Object where keys are language codes."""

    order: int


class Consent(BaseModel):
    """Consent management configuration."""

    enabled: bool

    button_text_translations: Optional[ButtonTextTranslation] = FieldInfo(alias="buttonTextTranslations", default=None)

    company_email: Optional[str] = FieldInfo(alias="companyEmail", default=None)

    company_name: Optional[str] = FieldInfo(alias="companyName", default=None)

    company_street_address: Optional[str] = FieldInfo(alias="companyStreetAddress", default=None)

    consent_modal_intro_html: Optional[str] = FieldInfo(alias="consentModalIntroHTML", default=None)

    consent_modal_intro_html_with_translations: Optional[Dict[str, str]] = FieldInfo(
        alias="consentModalIntroHTMLWithTranslations", default=None
    )
    """Object where keys are language codes."""

    cookie_name: Optional[str] = FieldInfo(alias="cookieName", default=None)

    custom_css: Optional[str] = FieldInfo(alias="customCSS", default=None)

    custom_intro_disclaimer_dismissed: Optional[bool] = FieldInfo(alias="customIntroDisclaimerDismissed", default=None)

    default_language: Optional[str] = FieldInfo(alias="defaultLanguage", default=None)

    hide_modal: Optional[bool] = FieldInfo(alias="hideModal", default=None)

    purposes: Optional[Dict[str, ConsentPurposes]] = None
    """Object where keys are purpose alpha-numeric IDs."""

    purposes_with_translations: Optional[Dict[str, ConsentPurposesWithTranslations]] = FieldInfo(
        alias="purposesWithTranslations", default=None
    )
    """Object where keys are purpose alpha-numeric IDs."""

    tcf_compliant: Optional[bool] = FieldInfo(alias="tcfCompliant", default=None)


class Configuration(BaseModel):
    """Zaraz configuration."""

    data_layer: bool = FieldInfo(alias="dataLayer")
    """Data layer compatibility mode enabled."""

    debug_key: str = FieldInfo(alias="debugKey")
    """The key for Zaraz debug mode."""

    settings: Settings
    """General Zaraz settings."""

    tools: Dict[str, Tools]
    """
    Tools set up under Zaraz configuration, where key is the alpha-numeric tool ID
    and value is the tool configuration object.
    """

    triggers: Dict[str, Triggers]
    """
    Triggers set up under Zaraz configuration, where key is the trigger
    alpha-numeric ID and value is the trigger configuration.
    """

    variables: Dict[str, Variables]
    """
    Variables set up under Zaraz configuration, where key is the variable
    alpha-numeric ID and value is the variable configuration. Values of variables of
    type secret are not included.
    """

    zaraz_version: int = FieldInfo(alias="zarazVersion")
    """Zaraz internal version of the config."""

    analytics: Optional[Analytics] = None
    """Cloudflare Monitoring settings."""

    consent: Optional[Consent] = None
    """Consent management configuration."""

    history_change: Optional[bool] = FieldInfo(alias="historyChange", default=None)
    """Single Page Application support enabled."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal, Required, TypedDict

from ..._types import SequenceNotStr

__all__ = ["ResourceSharingListParams"]


class ResourceSharingListParams(TypedDict, total=False):
    account_id: Required[str]
    """Account identifier."""

    direction: Literal["asc", "desc"]
    """Direction to sort objects."""

    include_recipient_counts: bool
    """Include recipient counts in the response."""

    include_resources: bool
    """Include resources in the response."""

    kind: Literal["sent", "received"]
    """Filter shares by kind."""

    order: Literal["name", "created"]
    """Order shares by values in the given field."""

    page: int
    """Page number."""

    per_page: int
    """Number of objects to return per page."""

    resource_types: List[
        Literal[
            "custom-ruleset",
            "gateway-policy",
            "gateway-destination-ip",
            "gateway-block-page-settings",
            "gateway-extended-email-matching",
            "idp-federation-grant",
        ]
    ]
    """Filter share resources by resource_types."""

    status: Literal["active", "deleting", "deleted"]
    """Filter shares by status."""

    tag: SequenceNotStr[str]
    """Filter shares by tag.

    Each value is either `key=value` (matches shares whose tags contain that
    key/value pair) or `key` alone (matches shares that have any value for that
    key). May be repeated; multiple `tag` parameters are ANDed together. Maximum 20
    `tag` parameters per request.
    """

    target_type: Literal["account", "organization"]
    """Filter shares by target_type."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import date

from ..._models import BaseModel

__all__ = ["DNS", "ReverseRecord"]


class ReverseRecord(BaseModel):
    first_seen: Optional[date] = None
    """First seen date of the DNS record during the time period."""

    hostname: Optional[str] = None
    """Hostname that the IP was observed resolving to."""

    last_seen: Optional[date] = None
    """Last seen date of the DNS record during the time period."""


class DNS(BaseModel):
    count: Optional[float] = None
    """Total results returned based on your search parameters."""

    page: Optional[float] = None
    """Current page within paginated list of results."""

    per_page: Optional[float] = None
    """Number of results per page of results."""

    reverse_records: Optional[List[ReverseRecord]] = None
    """Reverse DNS look-ups observed during the time period."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .dispatch import (
    DispatchResource,
    AsyncDispatchResource,
    DispatchResourceWithRawResponse,
    AsyncDispatchResourceWithRawResponse,
    DispatchResourceWithStreamingResponse,
    AsyncDispatchResourceWithStreamingResponse,
)
from .namespaces import (
    NamespacesResource,
    AsyncNamespacesResource,
    NamespacesResourceWithRawResponse,
    AsyncNamespacesResourceWithRawResponse,
    NamespacesResourceWithStreamingResponse,
    AsyncNamespacesResourceWithStreamingResponse,
)

__all__ = [
    "NamespacesResource",
    "AsyncNamespacesResource",
    "NamespacesResourceWithRawResponse",
    "AsyncNamespacesResourceWithRawResponse",
    "NamespacesResourceWithStreamingResponse",
    "AsyncNamespacesResourceWithStreamingResponse",
    "DispatchResource",
    "AsyncDispatchResource",
    "DispatchResourceWithRawResponse",
    "AsyncDispatchResourceWithRawResponse",
    "DispatchResourceWithStreamingResponse",
    "AsyncDispatchResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["AutomaticHTTPSRewritesParam"]


class AutomaticHTTPSRewritesParam(TypedDict, total=False):
    id: Literal["automatic_https_rewrites"]
    """Turn on or off Automatic HTTPS Rewrites."""

    value: Literal["on", "off"]
    """The status of Automatic HTTPS Rewrites."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["CustomHostnameListParams", "Hostname"]


class CustomHostnameListParams(TypedDict, total=False):
    zone_id: Required[str]
    """Identifier."""

    id: str
    """Hostname ID to match against.

    This ID was generated and returned during the initial custom_hostname creation.
    This parameter cannot be used with the 'hostname' parameter.
    """

    certificate_authority: Literal["google", "lets_encrypt", "ssl_com"]
    """Filter by the certificate authority that issued the SSL certificate."""

    custom_origin_server: str
    """Filter by custom origin server name."""

    direction: Literal["asc", "desc"]
    """Direction to order hostnames."""

    hostname: Hostname

    hostname_status: Literal[
        "active",
        "pending",
        "active_redeploying",
        "moved",
        "pending_deletion",
        "deleted",
        "pending_blocked",
        "pending_migration",
        "pending_provisioned",
        "test_pending",
        "test_active",
        "test_active_apex",
        "test_blocked",
        "test_failed",
        "provisioned",
        "blocked",
    ]
    """Filter by the hostname's activation status."""

    order: Literal["ssl", "ssl_status"]
    """Field to order hostnames by."""

    page: float
    """Page number of paginated results."""

    per_page: float
    """Number of hostnames per page."""

    ssl: Literal[0, 1]
    """Whether to filter hostnames based on if they have SSL enabled."""

    ssl_status: Literal[
        "initializing",
        "pending_validation",
        "deleted",
        "pending_issuance",
        "pending_deployment",
        "pending_deletion",
        "pending_expiration",
        "expired",
        "active",
        "initializing_timed_out",
        "validation_timed_out",
        "issuance_timed_out",
        "deployment_timed_out",
        "deletion_timed_out",
        "pending_cleanup",
        "staging_deployment",
        "staging_active",
        "deactivating",
        "inactive",
        "backup_issued",
        "holding_deployment",
    ]
    """Filter by SSL certificate status."""

    wildcard: bool
    """Filter by whether the custom hostname is a wildcard hostname."""


class Hostname(TypedDict, total=False):
    contain: str
    """Filters hostnames by a substring match on the hostname value.

    This parameter cannot be used with the 'id' parameter.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from typing_extensions import Literal

from ...._models import BaseModel

__all__ = ["DHCPServer", "DHCPOption"]


class DHCPOption(BaseModel):
    """A custom DHCP option to include in DHCP responses."""

    code: int
    """DHCP option number (1-254).

    Options 0 and 255 are reserved by RFC 2132. Options 3, 6, and 51 are not allowed
    because they conflict with connector-managed configuration.
    """

    type: Literal["text", "hex", "ip", "byte", "short", "integer"]
    """The type of the option value.

    text: a string (max 255 bytes). hex: colon-separated hex bytes (e.g.
    "01:04:aa:bb:cc", max 255 bytes). ip: an IPv4 address (e.g. "10.20.30.40").
    byte: an unsigned integer 0-255 (1 byte). short: an unsigned integer 0-65535 (2
    bytes). integer: an unsigned integer 0-4294967295 (4 bytes).
    """

    value: str
    """The option value, interpreted according to the type field."""


class DHCPServer(BaseModel):
    dhcp_options: Optional[List[DHCPOption]] = None
    """Optional list of custom DHCP options to include in DHCP responses.

    Only valid when DHCP server is enabled.
    """

    dhcp_pool_end: Optional[str] = None
    """A valid IPv4 address."""

    dhcp_pool_start: Optional[str] = None
    """A valid IPv4 address."""

    dns_server: Optional[str] = None
    """A valid IPv4 address."""

    dns_servers: Optional[List[str]] = None

    reservations: Optional[Dict[str, str]] = None
    """Mapping of MAC addresses to IP addresses"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["WhoisGetResponse"]


class WhoisGetResponse(BaseModel):
    dnssec: bool

    domain: str

    extension: str

    found: bool

    nameservers: List[str]

    punycode: str

    registrant: str

    registrar: str

    id: Optional[str] = None

    administrative_city: Optional[str] = None

    administrative_country: Optional[str] = None

    administrative_email: Optional[str] = None

    administrative_fax: Optional[str] = None

    administrative_fax_ext: Optional[str] = None

    administrative_id: Optional[str] = None

    administrative_name: Optional[str] = None

    administrative_org: Optional[str] = None

    administrative_phone: Optional[str] = None

    administrative_phone_ext: Optional[str] = None

    administrative_postal_code: Optional[str] = None

    administrative_province: Optional[str] = None

    administrative_referral_url: Optional[str] = None

    administrative_street: Optional[str] = None

    billing_city: Optional[str] = None

    billing_country: Optional[str] = None

    billing_email: Optional[str] = None

    billing_fax: Optional[str] = None

    billing_fax_ext: Optional[str] = None

    billing_id: Optional[str] = None

    billing_name: Optional[str] = None

    billing_org: Optional[str] = None

    billing_phone: Optional[str] = None

    billing_phone_ext: Optional[str] = None

    billing_postal_code: Optional[str] = None

    billing_province: Optional[str] = None

    billing_referral_url: Optional[str] = None

    billing_street: Optional[str] = None

    created_date: Optional[datetime] = None

    created_date_raw: Optional[str] = None

    expiration_date: Optional[datetime] = None

    expiration_date_raw: Optional[str] = None

    registrant_city: Optional[str] = None

    registrant_country: Optional[str] = None

    registrant_email: Optional[str] = None

    registrant_fax: Optional[str] = None

    registrant_fax_ext: Optional[str] = None

    registrant_id: Optional[str] = None

    registrant_name: Optional[str] = None

    registrant_org: Optional[str] = None

    registrant_phone: Optional[str] = None

    registrant_phone_ext: Optional[str] = None

    registrant_postal_code: Optional[str] = None

    registrant_province: Optional[str] = None

    registrant_referral_url: Optional[str] = None

    registrant_street: Optional[str] = None

    registrar_city: Optional[str] = None

    registrar_country: Optional[str] = None

    registrar_email: Optional[str] = None

    registrar_fax: Optional[str] = None

    registrar_fax_ext: Optional[str] = None

    registrar_id: Optional[str] = None

    registrar_name: Optional[str] = None

    registrar_org: Optional[str] = None

    registrar_phone: Optional[str] = None

    registrar_phone_ext: Optional[str] = None

    registrar_postal_code: Optional[str] = None

    registrar_province: Optional[str] = None

    registrar_referral_url: Optional[str] = None

    registrar_street: Optional[str] = None

    status: Optional[List[str]] = None

    technical_city: Optional[str] = None

    technical_country: Optional[str] = None

    technical_email: Optional[str] = None

    technical_fax: Optional[str] = None

    technical_fax_ext: Optional[str] = None

    technical_id: Optional[str] = None

    technical_name: Optional[str] = None

    technical_org: Optional[str] = None

    technical_phone: Optional[str] = None

    technical_phone_ext: Optional[str] = None

    technical_postal_code: Optional[str] = None

    technical_province: Optional[str] = None

    technical_referral_url: Optional[str] = None

    technical_street: Optional[str] = None

    updated_date: Optional[datetime] = None

    updated_date_raw: Optional[str] = None

    whois_server: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .summary import (
    SummaryResource,
    AsyncSummaryResource,
    SummaryResourceWithRawResponse,
    AsyncSummaryResourceWithRawResponse,
    SummaryResourceWithStreamingResponse,
    AsyncSummaryResourceWithStreamingResponse,
)
from .behaviours import (
    BehavioursResource,
    AsyncBehavioursResource,
    BehavioursResourceWithRawResponse,
    AsyncBehavioursResourceWithRawResponse,
    BehavioursResourceWithStreamingResponse,
    AsyncBehavioursResourceWithStreamingResponse,
)
from .integrations import (
    IntegrationsResource,
    AsyncIntegrationsResource,
    IntegrationsResourceWithRawResponse,
    AsyncIntegrationsResourceWithRawResponse,
    IntegrationsResourceWithStreamingResponse,
    AsyncIntegrationsResourceWithStreamingResponse,
)
from .risk_scoring import (
    RiskScoringResource,
    AsyncRiskScoringResource,
    RiskScoringResourceWithRawResponse,
    AsyncRiskScoringResourceWithRawResponse,
    RiskScoringResourceWithStreamingResponse,
    AsyncRiskScoringResourceWithStreamingResponse,
)

__all__ = [
    "BehavioursResource",
    "AsyncBehavioursResource",
    "BehavioursResourceWithRawResponse",
    "AsyncBehavioursResourceWithRawResponse",
    "BehavioursResourceWithStreamingResponse",
    "AsyncBehavioursResourceWithStreamingResponse",
    "SummaryResource",
    "AsyncSummaryResource",
    "SummaryResourceWithRawResponse",
    "AsyncSummaryResourceWithRawResponse",
    "SummaryResourceWithStreamingResponse",
    "AsyncSummaryResourceWithStreamingResponse",
    "IntegrationsResource",
    "AsyncIntegrationsResource",
    "IntegrationsResourceWithRawResponse",
    "AsyncIntegrationsResourceWithRawResponse",
    "IntegrationsResourceWithStreamingResponse",
    "AsyncIntegrationsResourceWithStreamingResponse",
    "RiskScoringResource",
    "AsyncRiskScoringResource",
    "RiskScoringResourceWithRawResponse",
    "AsyncRiskScoringResourceWithRawResponse",
    "RiskScoringResourceWithStreamingResponse",
    "AsyncRiskScoringResourceWithStreamingResponse",
]
